@@ -380,8 +380,7 @@ class Patcher:
 
     SKIPNAMES = {'os', 'path', 'io', 'genericpath', OS_MODULE, PATH_MODULE}
 
-    # hold values from last call - if changed, the cache in
-    # CACHED_SKIPMODULES has to be invalidated
+    # hold values from last call - if changed, the cache has to be invalidated
     PATCHED_MODULE_NAMES = {}
     ADDITIONAL_SKIP_NAMES = set()
     PATCH_DEFAULT_ARGS = False
@@ -432,7 +431,6 @@ class Patcher:
         self._skip_names = self.SKIPNAMES.copy()
         # save the original open function for use in pytest plugin
         self.original_open = open
-        self.fake_open = None
         self.patch_open_code = patch_open_code
 
         if additional_skip_names is not None:
@@ -701,7 +699,6 @@ class Patcher:
             if hasattr(self.fake_modules[name], 'skip_names'):
                 self.fake_modules[name].skip_names = self._skip_names
         self.fake_modules[PATH_MODULE] = self.fake_modules['os'].path
-        self.fake_open = fake_filesystem.FakeFileOpen(self.fs)
         for name in self._unfaked_module_classes:
             self.unfaked_modules[name] = self._unfaked_module_classes[name]()
 
